# QebHwtThamosAdviseInput

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**github_event_type** | **str** | Type of GitHub event. |
**github_check_run_id** | **int** | ID of the check-run that shall carry the thamos advise. |
**github_installation_id** | **int** | GitHub App Installation ID. |
**github_base_repo_url** | **str** | URL of the GitHub repository containing the Pull Request. |
**github_head_repo_url** | **str** | URL of the Pull Request&#x27;s head commit. |
**origin** | **str** | Origin of the repo where the Pull Request was opened. |
**revision** | **str** | sha of the Pull Request&#x27;s head commit. |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
